"""
    Mixer is a python module that adds object generation
    tool for testing your application.

    It's supported Django_ ORM, SQLAlchemy_ ORM, Mongoengine_ ODM and etc.

    Mixer is very useful for testing and fixtures replacement.

    :copyright: 2013 by Kirill Klenov.
    :license: BSD, see LICENSE for more details.
"""
from __future__ import unicode_literals

# Module information
# ==================

__version__ = '0.11.1'
__project__ = 'mixer'
__author__ = "horneds <horneds@gmail.com>"
__license__ = "BSD"
